#!/usr/bin/env python3

try:
    import weechat
    import_ok = True
except ImportError:
    import_ok = False
import sys


SCRIPT_AUTHOR = 'snow flurry <snow@datagirl.xyz>'
SCRIPT_NAME = 'away_on_lock'
SCRIPT_VERSION = '0.5'
SCRIPT_LICENSE = 'MIT'
SCRIPT_DESC = 'Sends /away on lock'

DEFAULT_OPTIONS = {
    'verbose': 'on',
    'message': 'Screen locked',
}

def locknotify_cb(data, command, return_code, out, err):
    if return_code == weechat.WEECHAT_HOOK_PROCESS_ERROR:
        weechat.prnt("", "locknotify returned error: %s" % err)
        weechat.prnt("", "out: %s" % out)
        return weechat.WEECHAT_RC_OK

    verbose = weechat.config_boolean(weechat.config_get_plugin('verbose'))

    if out != "":
        out = out.strip()
        if out == "lock":
            weechat.prnt("", "screen locked, setting away...") if verbose else ()
            weechat.command("", "/away -all %s"
                            % weechat.config_get_plugin('message'))
        elif out == "unlock":
            weechat.prnt("", "screen unlocked, setting back...") if verbose else ()
            weechat.command("", "/away -all")
        else:
            weechat.prnt("", "unknown output: %s" % out)
    else:
        weechat.prnt("", "stderr: %s" % err)
    
    if return_code != weechat.WEECHAT_HOOK_PROCESS_RUNNING:
        spawn_helper()
    
    return weechat.WEECHAT_RC_OK

def spawn_helper():
    verbose = weechat.config_boolean(weechat.config_get_plugin('verbose'))
    print("spawning '%s'" % proc) if verbose else ()

    hook = weechat.hook_process(proc, 0, "locknotify_cb", "")

if import_ok:
    weechat.register(SCRIPT_NAME, SCRIPT_AUTHOR, SCRIPT_VERSION, SCRIPT_LICENSE, SCRIPT_DESC, "", "")
    
    for key, val in DEFAULT_OPTIONS.items():
        if not weechat.config_is_set_plugin(key):
            weechat.config_set_plugin(key, val)

    proc = "%s --selfhost" % __file__
    spawn_helper()


elif __name__ == "__main__":
    if len(sys.argv) < 2 or sys.argv[1] != "--selfhost":
        print('This script must be run from WeeChat.')
        sys.exit(1)

    # pyobjc gets upset if we reimport in the same exec runtime, so
    # wait to import it until here!
    try:
        import importlib
        notify = importlib.import_module("notify_%s" % sys.platform)
    except ImportError:
        print('No OS-specific module notify_%s found.' % sys.platform, file=sys.stderr)

    notify.notify_lock(lambda status: print(status))
